<!--
When reporting a bug or unexpected behavior,
please include this information unless you are absolutely sure it is irrelevant:

- WhatsHap and Python version (`python -V` and `whatshap --version`)
- How you installed the tool (conda, pip)
- Which command-line parameters you used

Avoid pasting a screenshot. Instead, please copy and paste the text directly
into the issue.

Feel free to delete this text before submitting your issue.
-->
